//! Show predefined patterns on the micro:bit led display and switch between them using its
//! buttons.

#![no_std]
#![no_main]

use embassy_executor::Spawner;
use embassy_nrf::gpio::Pin;
use {defmt_rtt as _, panic_probe as _};

mod buttons;
mod leds;
mod patterns;
mod state;

/// Setup the necessary micro:bit hardware and spawn the worker tasks.
#[embassy_executor::main]
async fn main(spawner: Spawner) {
    let p = embassy_nrf::init(Default::default());
    let rows = [
        p.P0_21.degrade(),
        p.P0_22.degrade(),
        p.P0_15.degrade(),
        p.P0_24.degrade(),
        p.P0_19.degrade(),
    ];
    let cols = [
        p.P0_28.degrade(),
        p.P0_11.degrade(),
        p.P0_31.degrade(),
        p.P1_05.degrade(),
        p.P0_30.degrade(),
    ];

    let button_left = p.P0_14.degrade();
    let button_right = p.P0_23.degrade();

    spawner
        .spawn(state::task())
        .expect("state task failed to start");
    spawner
        .spawn(leds::task(rows, cols))
        .expect("led task failed to start");
    buttons::spawn(spawner, button_left, button_right).expect("button task failed to start");
}
